@@ -384,18 +384,9 @@ class PromptChatbot(Chatbot):
             Dict[str, Any]: Dictionary of attributes that defines this instance of a
                 PromptChatbot.
         """
-        return {
-            "co": self.co,
-            "prompt": self.prompt.to_dict(),
-            "persona_name": self.persona_name,
-            "chatbot_config": self.chatbot_config,
-            "client_config": self.client_config,
-            "chat_history": self.chat_history,
-            "prompt_history": self.prompt_history,
-            "user_name": self.user_name,
-            "bot_name": self.bot_name,
-            "latest_prompt": self.latest_prompt,
-        }
+        attr_dict = {k: v for k, v in vars(self).items()}
+        attr_dict["prompt"] = attr_dict["prompt"].to_dict()
+        return attr_dict
 
     def _check_prompt_size(self) -> None:
 
